"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createResource = void 0;
const internal_1 = require("../common/internal");
function createResource(resource) {
    return {
        attributes: (0, internal_1.toAttributes)(resource.attributes),
        droppedAttributesCount: 0,
    };
}
exports.createResource = createResource;
//# sourceMappingURL=internal.js.map