import type { ResourceMetrics } from '@opentelemetry/sdk-metrics';
import type { IExportMetricsServiceRequest } from './types';
import type { OtlpEncodingOptions } from '../common/types';
export declare function createExportMetricsServiceRequest(resourceMetrics: ResourceMetrics[], options?: OtlpEncodingOptions): IExportMetricsServiceRequest;
//# sourceMappingURL=index.d.ts.map