/**
 * Serializes and deserializes the OTLP request/response to and from {@link Uint8Array}
 */
export interface ISerializer<Request, Response> {
    serializeRequest(request: Request): Uint8Array | undefined;
    deserializeResponse(data: Uint8Array): Response;
}
//# sourceMappingURL=i-serializer.d.ts.map