import { IResource as ISdkResource } from '@opentelemetry/resources';
import { IResource } from './types';
export declare function createResource(resource: ISdkResource): IResource;
//# sourceMappingURL=internal.d.ts.map